pitchtools.octave_tick_string_to_octave_number
==============================================

.. autofunction:: abjad.tools.pitchtools.octave_tick_string_to_octave_number.octave_tick_string_to_octave_number
